﻿using BonsPratos.Database;
using BonsPratos.Diversos;
using BonsPratos.Model;
using SQLite.Net;
using System.IO;
using System.Xml;
using Windows.Storage;
using Windows.UI.Popups;
using Xamarin.Forms;
using System;

[assembly: Dependency(typeof(BonsPratos.UWP.Backup_UWP))]

namespace BonsPratos.UWP
{
    public class Backup_UWP : IBackup
    {
        MensagemUWP Mensagem = new MensagemUWP();

        public void CriarBackup()
        {
            try
            {
                string strDiretorio = ApplicationData.Current.LocalFolder.Path;
                string strNomeArquivo = Path.Combine(strDiretorio, "BonsPratos.xml");
                FileStream fsArquivo = new FileStream(strNomeArquivo, FileMode.OpenOrCreate, FileAccess.Write);
                StreamWriter swArquivo = new StreamWriter(fsArquivo);

                SQLiteConnection BancoDados = DependencyService.Get<IConexaoDB>().GetConnection("BonsPratosDb.db3");

                var varConsulta = BancoDados.Table<Estabelecimentos>().OrderBy(c => c.NomeEstabelecimento);

                XmlWriter xmlDocumento = XmlWriter.Create(swArquivo);

                xmlDocumento.WriteStartDocument();
                xmlDocumento.WriteStartElement("BonsPratos");

                foreach (var varRegistro in varConsulta)
                {
                    xmlDocumento.WriteStartElement("DadosEstabelecimento");
                    xmlDocumento.WriteStartElement("NomeEstabelecimento");
                    xmlDocumento.WriteString(varRegistro.NomeEstabelecimento);
                    xmlDocumento.WriteEndElement();
                    xmlDocumento.WriteStartElement("TipoEstabelecimento");
                    xmlDocumento.WriteString(varRegistro.TipoEstabelecimento.ToString());
                    xmlDocumento.WriteEndElement();
                    xmlDocumento.WriteStartElement("Endereco");
                    xmlDocumento.WriteString(varRegistro.Endereco);
                    xmlDocumento.WriteEndElement();
                    xmlDocumento.WriteStartElement("Bairro");
                    xmlDocumento.WriteString(varRegistro.Bairro);
                    xmlDocumento.WriteEndElement();
                    xmlDocumento.WriteStartElement("Cidade");
                    xmlDocumento.WriteString(varRegistro.Cidade);
                    xmlDocumento.WriteEndElement();
                    xmlDocumento.WriteStartElement("Estado");
                    xmlDocumento.WriteString(varRegistro.Estado.ToString());
                    xmlDocumento.WriteEndElement();
                    xmlDocumento.WriteStartElement("Telefone");
                    xmlDocumento.WriteString(varRegistro.Telefone);
                    xmlDocumento.WriteEndElement();
                    xmlDocumento.WriteStartElement("Email");
                    xmlDocumento.WriteString(varRegistro.Email);
                    xmlDocumento.WriteEndElement();
                    xmlDocumento.WriteStartElement("NivelAtendimento");
                    xmlDocumento.WriteString(varRegistro.NivelAtendimento.ToString());
                    xmlDocumento.WriteEndElement();
                    xmlDocumento.WriteStartElement("QualidadePrato");
                    xmlDocumento.WriteString(varRegistro.QualidadePrato.ToString());
                    xmlDocumento.WriteEndElement();
                    xmlDocumento.WriteStartElement("ClassificacaoPreco");
                    xmlDocumento.WriteString(varRegistro.ClassificacaoPreco.ToString());
                    xmlDocumento.WriteEndElement();
                    xmlDocumento.WriteStartElement("TipoLocalizacao");
                    xmlDocumento.WriteString(varRegistro.TipoLocalizacao.ToString());
                    xmlDocumento.WriteEndElement();
                    xmlDocumento.WriteStartElement("Latitude");
                    xmlDocumento.WriteString(varRegistro.Latitude.ToString());
                    xmlDocumento.WriteEndElement();
                    xmlDocumento.WriteStartElement("Longitude");
                    xmlDocumento.WriteString(varRegistro.Longitude.ToString());
                    xmlDocumento.WriteEndElement();
                    xmlDocumento.WriteStartElement("ArquivoFoto");
                    xmlDocumento.WriteString(varRegistro.ArquivoFoto);
                    xmlDocumento.WriteEndElement();
                    xmlDocumento.WriteEndElement();
                }

                xmlDocumento.WriteEndElement();
                xmlDocumento.WriteEndDocument();
                xmlDocumento.Flush();
                xmlDocumento.Dispose();

                ExibirMensagem("Arquivo [" + strNomeArquivo + "] gerado com sucesso!");
            }
            catch
            {
                ExibirMensagem("Não foi possível gravar o arquivo de backup!");
            }
        }

        public void RestaurarBackup()
        {
            try
            {
                Estabelecimentos estabelecimento = new Estabelecimentos();

                string strDiretorio = ApplicationData.Current.LocalFolder.Path;
                string strNomeArquivo = Path.Combine(strDiretorio, "BonsPratos.xml");

                SQLiteConnection BancoDados = DependencyService.Get<IConexaoDB>().GetConnection("BonsPratosDb.db3");
                BancoDados.DropTable<Estabelecimentos>();
                BancoDados.CreateTable<Estabelecimentos>();

                XmlReader xmlDocumento = XmlReader.Create(strNomeArquivo);

                xmlDocumento.MoveToContent();

                while (xmlDocumento.Read())
                {
                    if ((xmlDocumento.NodeType == XmlNodeType.Element) && (xmlDocumento.Name == "NomeEstabelecimento"))
                        estabelecimento.NomeEstabelecimento = xmlDocumento.ReadElementContentAsString();

                    if ((xmlDocumento.NodeType == XmlNodeType.Element) && (xmlDocumento.Name == "TipoEstabelecimento"))
                        estabelecimento.TipoEstabelecimento = xmlDocumento.ReadElementContentAsInt();

                    if ((xmlDocumento.NodeType == XmlNodeType.Element) && (xmlDocumento.Name == "Endereco"))
                        estabelecimento.Endereco = xmlDocumento.ReadElementContentAsString();

                    if ((xmlDocumento.NodeType == XmlNodeType.Element) && (xmlDocumento.Name == "Bairro"))
                        estabelecimento.Bairro = xmlDocumento.ReadElementContentAsString();

                    if ((xmlDocumento.NodeType == XmlNodeType.Element) && (xmlDocumento.Name == "Cidade"))
                        estabelecimento.Cidade = xmlDocumento.ReadElementContentAsString();

                    if ((xmlDocumento.NodeType == XmlNodeType.Element) && (xmlDocumento.Name == "Estado"))
                        estabelecimento.Estado = xmlDocumento.ReadElementContentAsInt();

                    if ((xmlDocumento.NodeType == XmlNodeType.Element) && (xmlDocumento.Name == "Telefone"))
                        estabelecimento.Telefone = xmlDocumento.ReadElementContentAsString();

                    if ((xmlDocumento.NodeType == XmlNodeType.Element) && (xmlDocumento.Name == "Email"))
                        estabelecimento.Email = xmlDocumento.ReadElementContentAsString();

                    if ((xmlDocumento.NodeType == XmlNodeType.Element) && (xmlDocumento.Name == "NivelAtendimento"))
                        estabelecimento.NivelAtendimento = xmlDocumento.ReadElementContentAsInt();

                    if ((xmlDocumento.NodeType == XmlNodeType.Element) && (xmlDocumento.Name == "QualidadePrato"))
                        estabelecimento.QualidadePrato = xmlDocumento.ReadElementContentAsInt();

                    if ((xmlDocumento.NodeType == XmlNodeType.Element) && (xmlDocumento.Name == "ClassificacaoPreco"))
                        estabelecimento.ClassificacaoPreco = xmlDocumento.ReadElementContentAsInt();

                    if ((xmlDocumento.NodeType == XmlNodeType.Element) && (xmlDocumento.Name == "TipoLocalizacao"))
                        estabelecimento.TipoLocalizacao = xmlDocumento.ReadElementContentAsInt();

                    if ((xmlDocumento.NodeType == XmlNodeType.Element) && (xmlDocumento.Name == "Latitude"))
                        estabelecimento.Latitude = Funcoes.StrToDbl(xmlDocumento.ReadElementContentAsString());

                    if ((xmlDocumento.NodeType == XmlNodeType.Element) && (xmlDocumento.Name == "Longitude"))
                        estabelecimento.Longitude = Funcoes.StrToDbl(xmlDocumento.ReadElementContentAsString());

                    if ((xmlDocumento.NodeType == XmlNodeType.Element) && (xmlDocumento.Name == "ArquivoFoto"))
                    {
                        estabelecimento.ArquivoFoto = xmlDocumento.ReadElementContentAsString();
                        BancoDados.Insert(estabelecimento);
                    }
                }

                ExibirMensagem("Restauração efetuada com sucesso!");
            }
            catch
            {
                ExibirMensagem("Não foi possível restaurar os dados do backup!");
            }
        }

        private async void ExibirMensagem(string strMensagem)
        {
            var Alerta = new MessageDialog(strMensagem, "Mensagem de Alerta");
            await Alerta.ShowAsync();
        }
    }
}
