﻿using BonsPratos.Database;
using BonsPratos.Diversos;
using BonsPratos.Model;
using SQLite.Net;
using System;
using System.IO;
using System.Xml;
using Xamarin.Forms;
using UIKit;

[assembly: Dependency(typeof(BonsPratos.iOS.Backup_iOS))]

namespace BonsPratos.iOS
{
    public class Backup_iOS : IBackup
    {
        public void CriarBackup()
        {
            try
            {
                string strPastaDocumentos = Environment.GetFolderPath(Environment.SpecialFolder.Personal);
                string strPastaBiblioteca = Path.Combine(strPastaDocumentos, "..", "Library");
                string strNomeArquivo = Path.Combine(strPastaBiblioteca, "BonsPratos.xml");

                SQLiteConnection BancoDados = DependencyService.Get<IConexaoDB>().GetConnection("BonsPratosDb.db3");

                var varConsulta = BancoDados.Table<Estabelecimentos>().OrderBy(c => c.NomeEstabelecimento);

                XmlWriter xmlDocumento = XmlWriter.Create(strNomeArquivo);

                xmlDocumento.WriteStartDocument();
                xmlDocumento.WriteStartElement("BonsPratos");

                foreach (var varRegistro in varConsulta)
                {
                    xmlDocumento.WriteStartElement("DadosEstabelecimento");
                    xmlDocumento.WriteStartElement("NomeEstabelecimento");
                    xmlDocumento.WriteString(varRegistro.NomeEstabelecimento);
                    xmlDocumento.WriteEndElement();
                    xmlDocumento.WriteStartElement("TipoEstabelecimento");
                    xmlDocumento.WriteString(varRegistro.TipoEstabelecimento.ToString());
                    xmlDocumento.WriteEndElement();
                    xmlDocumento.WriteStartElement("Endereco");
                    xmlDocumento.WriteString(varRegistro.Endereco);
                    xmlDocumento.WriteEndElement();
                    xmlDocumento.WriteStartElement("Bairro");
                    xmlDocumento.WriteString(varRegistro.Bairro);
                    xmlDocumento.WriteEndElement();
                    xmlDocumento.WriteStartElement("Cidade");
                    xmlDocumento.WriteString(varRegistro.Cidade);
                    xmlDocumento.WriteEndElement();
                    xmlDocumento.WriteStartElement("Estado");
                    xmlDocumento.WriteString(varRegistro.Estado.ToString());
                    xmlDocumento.WriteEndElement();
                    xmlDocumento.WriteStartElement("Telefone");
                    xmlDocumento.WriteString(varRegistro.Telefone);
                    xmlDocumento.WriteEndElement();
                    xmlDocumento.WriteStartElement("Email");
                    xmlDocumento.WriteString(varRegistro.Email);
                    xmlDocumento.WriteEndElement();
                    xmlDocumento.WriteStartElement("NivelAtendimento");
                    xmlDocumento.WriteString(varRegistro.NivelAtendimento.ToString());
                    xmlDocumento.WriteEndElement();
                    xmlDocumento.WriteStartElement("QualidadePrato");
                    xmlDocumento.WriteString(varRegistro.QualidadePrato.ToString());
                    xmlDocumento.WriteEndElement();
                    xmlDocumento.WriteStartElement("ClassificacaoPreco");
                    xmlDocumento.WriteString(varRegistro.ClassificacaoPreco.ToString());
                    xmlDocumento.WriteEndElement();
                    xmlDocumento.WriteStartElement("TipoLocalizacao");
                    xmlDocumento.WriteString(varRegistro.TipoLocalizacao.ToString());
                    xmlDocumento.WriteEndElement();
                    xmlDocumento.WriteStartElement("Latitude");
                    xmlDocumento.WriteString(varRegistro.Latitude.ToString());
                    xmlDocumento.WriteEndElement();
                    xmlDocumento.WriteStartElement("Longitude");
                    xmlDocumento.WriteString(varRegistro.Longitude.ToString());
                    xmlDocumento.WriteEndElement();
                    xmlDocumento.WriteStartElement("ArquivoFoto");
                    xmlDocumento.WriteString(varRegistro.ArquivoFoto);
                    xmlDocumento.WriteEndElement();
                    xmlDocumento.WriteEndElement();
                }

                xmlDocumento.WriteEndElement();
                xmlDocumento.WriteEndDocument();
                xmlDocumento.Close();

                ExibirMensagem("Arquivo [" + strNomeArquivo + "] gerado com sucesso!");
            }
            catch
            {
                ExibirMensagem("Não foi possível gravar o arquivo de backup!");
            }
        }

        public void RestaurarBackup()
        {
            try
            {
                Estabelecimentos estabelecimento = new Estabelecimentos();

                string strPastaDocumentos = Environment.GetFolderPath(Environment.SpecialFolder.Personal);
                string strPastaBiblioteca = Path.Combine(strPastaDocumentos, "..", "Library");
                string strNomeArquivo = Path.Combine(strPastaBiblioteca, "BonsPratos.xml");

                SQLiteConnection BancoDados = DependencyService.Get<IConexaoDB>().GetConnection("BonsPratosDb.db3");
                BancoDados.DropTable<Estabelecimentos>();
                BancoDados.CreateTable<Estabelecimentos>();

                XmlReader xmlDocumento = XmlReader.Create(strNomeArquivo);

                xmlDocumento.MoveToContent();

                while (xmlDocumento.Read())
                {
                    if ((xmlDocumento.NodeType == XmlNodeType.Element) && (xmlDocumento.Name == "NomeEstabelecimento"))
                        estabelecimento.NomeEstabelecimento = xmlDocumento.ReadElementContentAsString();

                    if ((xmlDocumento.NodeType == XmlNodeType.Element) && (xmlDocumento.Name == "TipoEstabelecimento"))
                        estabelecimento.TipoEstabelecimento = xmlDocumento.ReadElementContentAsInt();

                    if ((xmlDocumento.NodeType == XmlNodeType.Element) && (xmlDocumento.Name == "Endereco"))
                        estabelecimento.Endereco = xmlDocumento.ReadElementContentAsString();

                    if ((xmlDocumento.NodeType == XmlNodeType.Element) && (xmlDocumento.Name == "Bairro"))
                        estabelecimento.Bairro = xmlDocumento.ReadElementContentAsString();

                    if ((xmlDocumento.NodeType == XmlNodeType.Element) && (xmlDocumento.Name == "Cidade"))
                        estabelecimento.Cidade = xmlDocumento.ReadElementContentAsString();

                    if ((xmlDocumento.NodeType == XmlNodeType.Element) && (xmlDocumento.Name == "Estado"))
                        estabelecimento.Estado = xmlDocumento.ReadElementContentAsInt();

                    if ((xmlDocumento.NodeType == XmlNodeType.Element) && (xmlDocumento.Name == "Telefone"))
                        estabelecimento.Telefone = xmlDocumento.ReadElementContentAsString();

                    if ((xmlDocumento.NodeType == XmlNodeType.Element) && (xmlDocumento.Name == "Email"))
                        estabelecimento.Email = xmlDocumento.ReadElementContentAsString();

                    if ((xmlDocumento.NodeType == XmlNodeType.Element) && (xmlDocumento.Name == "NivelAtendimento"))
                        estabelecimento.NivelAtendimento = xmlDocumento.ReadElementContentAsInt();

                    if ((xmlDocumento.NodeType == XmlNodeType.Element) && (xmlDocumento.Name == "QualidadePrato"))
                        estabelecimento.QualidadePrato = xmlDocumento.ReadElementContentAsInt();

                    if ((xmlDocumento.NodeType == XmlNodeType.Element) && (xmlDocumento.Name == "ClassificacaoPreco"))
                        estabelecimento.ClassificacaoPreco = xmlDocumento.ReadElementContentAsInt();

                    if ((xmlDocumento.NodeType == XmlNodeType.Element) && (xmlDocumento.Name == "TipoLocalizacao"))
                        estabelecimento.TipoLocalizacao = xmlDocumento.ReadElementContentAsInt();

                    if ((xmlDocumento.NodeType == XmlNodeType.Element) && (xmlDocumento.Name == "Latitude"))
                        estabelecimento.Latitude = Funcoes.StrToDbl(xmlDocumento.ReadElementContentAsString());

                    if ((xmlDocumento.NodeType == XmlNodeType.Element) && (xmlDocumento.Name == "Longitude"))
                        estabelecimento.Longitude = Funcoes.StrToDbl(xmlDocumento.ReadElementContentAsString());

                    if ((xmlDocumento.NodeType == XmlNodeType.Element) && (xmlDocumento.Name == "ArquivoFoto"))
                    {
                        estabelecimento.ArquivoFoto = xmlDocumento.ReadElementContentAsString();
                        BancoDados.Insert(estabelecimento);
                    }
                }

                ExibirMensagem("Restauração efetuada com sucesso!");
            }
            catch
            {
                ExibirMensagem("Não foi possível restaurar os dados do backup!");
            }
        }

        private void ExibirMensagem(string strMensagem)
        {
            UIAlertView Alerta = new UIAlertView()
            {
                Title = "Mensagem alerta",
                Message = strMensagem
            };

            Alerta.AddButton("OK");
            Alerta.Show();
        }
    }
}
