﻿using SQLite.Net.Attributes;
using System.ComponentModel;

namespace BonsPratos.Model
{
    [Table("Estabelecimentos")]

    public class Estabelecimentos : INotifyPropertyChanged
    {
        private int intIDRegistro;
        private string strNomeEstabelecimento;
        private int intTipoEstabelecimento;
        private string strEndereco;
        private string strBairro;
        private string strCidade;
        private int intEstado;
        private string strTelefone;
        private string strEmail;
        private int intNivelAtendimento;
        private int intQualidadePrato;
        private int intClassificacaoPreco;
        private int intTipoLocalizacao;
        private double dblLatitude;
        private double dblLongitude;
        private string strArquivoFoto;

        private string[] _SiglaUF = {"AC","AL","AP","AM","BA","CE","DF","ES","GO","MA","MT","MS","MG","PR","PB","PA","PE","PI","RN","RS","RJ","RO","RR","SC","SE","SP","TO" };
        private string[] _TipoEstabelecimento = { "Restaurante", "Lanchonete", "Pizzaria", "Churrascaria", "Choperia", "Padaria", "Barzinho/Pub" };
        private string[] _NivelAtendimento = { "Péssimo", "Ruim", "Regular", "Bom", "Excelente" };
        private string[] _QualidadePrato = { "Péssima", "Ruim", "Regular", "Boa", "Excelente" };
        private string[] _ClassificacaoPreco = { "Baixo", "Regular", "Aceitável", "Alto" };
        private string[] _TipoLocalizacao = { "Péssima", "Ruim", "Difícil acesso", "Boa", "Excelente" };

        [PrimaryKey, AutoIncrement]
        public int IDRegistro
        {
            get
            {
                return intIDRegistro;
            }
            set
            {
                this.intIDRegistro = value;
                OnPropertyChanged(nameof(IDRegistro));
            }
        }

        [MaxLength(30)]
        public string NomeEstabelecimento
        {
            get
            {
                return strNomeEstabelecimento;
            }
            set
            {
                this.strNomeEstabelecimento = value;
                OnPropertyChanged(nameof(NomeEstabelecimento));
            }
        }

        public int TipoEstabelecimento
        {
            get
            {
                return intTipoEstabelecimento;
            }
            set
            {
                this.intTipoEstabelecimento = value;
                OnPropertyChanged(nameof(TipoEstabelecimento));
            }
        }

        [MaxLength(50)]
        public string Endereco
        {
            get
            {
                return strEndereco;
            }
            set
            {
                strEndereco = value;
                OnPropertyChanged(nameof(Endereco));
            }
        }

        [MaxLength(40)]
        public string Bairro
        {
            get
            {
                return strBairro;
            }
            set
            {
                strBairro = value;
                OnPropertyChanged(nameof(Bairro));
            }
        }

        [MaxLength(40)]
        public string Cidade
        {
            get
            {
                return strCidade;
            }
            set
            {
                strCidade = value;
                OnPropertyChanged(nameof(Cidade));
            }
        }

        public int Estado
        {
            get
            {
                return intEstado;
            }
            set
            {
                intEstado = value;
                OnPropertyChanged(nameof(Estado));
            }
        }

        [MaxLength(20)]
        public string Telefone
        {
            get
            {
                return strTelefone;
            }
            set
            {
                strTelefone = value;
                OnPropertyChanged(nameof(Telefone));
            }
        }

        [MaxLength(50)]
        public string Email
        {
            get
            {
                return strEmail;
            }
            set
            {
                strEmail = value;
                OnPropertyChanged(nameof(Email));
            }
        }

        public int NivelAtendimento
        {
            get
            {
                return intNivelAtendimento;
            }
            set
            {
                this.intNivelAtendimento = value;
                OnPropertyChanged(nameof(NivelAtendimento));
            }
        }

        public int QualidadePrato
        {
            get
            {
                return intQualidadePrato;
            }
            set
            {
                this.intQualidadePrato = value;
                OnPropertyChanged(nameof(QualidadePrato));
            }
        }

        public int ClassificacaoPreco
        {
            get
            {
                return intClassificacaoPreco;
            }
            set
            {
                this.intClassificacaoPreco = value;
                OnPropertyChanged(nameof(ClassificacaoPreco));
            }
        }

        public int TipoLocalizacao
        {
            get
            {
                return intTipoLocalizacao;
            }
            set
            {
                this.intTipoLocalizacao = value;
                OnPropertyChanged(nameof(TipoLocalizacao));
            }
        }

        public double Latitude
        {
            get
            {
                return dblLatitude;
            }
            set
            {
                this.dblLatitude = value;
                OnPropertyChanged(nameof(Latitude));
            }
        }

        public double Longitude
        {
            get
            {
                return dblLongitude;
            }
            set
            {
                this.dblLongitude = value;
                OnPropertyChanged(nameof(Longitude));
            }
        }

        [MaxLength(50)]
        public string ArquivoFoto
        {
            get
            {
                return strArquivoFoto;
            }
            set
            {
                strArquivoFoto = value;
                OnPropertyChanged(nameof(ArquivoFoto));
            }
        }

        public string DescricaoTipoEstabelecimento
        {
            get
            {
                return _TipoEstabelecimento[intTipoEstabelecimento];
            }
        }

        public string Cidade_UF
        {
            get
            {
                return Cidade + "/" + _SiglaUF[Estado];
            }
        }

        public string DescricaoNivelAtendimento
        {
            get
            {
                return _NivelAtendimento[intNivelAtendimento];
            }
        }

        public string DescricaoQualidadePrato
        {
            get
            {
                return _QualidadePrato[intQualidadePrato];
            }
        }

        public string DescricaoClassificacaoPreco
        {
            get
            {
                return _ClassificacaoPreco[intClassificacaoPreco];
            }
        }

        public string DescricaoTipoLocalizacao
        {
            get
            {
                return _TipoLocalizacao[intTipoLocalizacao];
            }
        }

        public event PropertyChangedEventHandler PropertyChanged;

        private void OnPropertyChanged(string NomePropriedade)
        {
            this.PropertyChanged?.Invoke(this, new PropertyChangedEventArgs(NomePropriedade));
        }
    }
}
