﻿using BonsPratos.Database;
using BonsPratos.Model;
using Plugin.Geolocator;
using Plugin.Media;
using Plugin.Media.Abstractions;
using System;
using Xamarin.Forms;
using Xamarin.Forms.Xaml;

namespace BonsPratos.View
{
    [XamlCompilation(XamlCompilationOptions.Compile)]
    public partial class TelaCadastro : TabbedPage
    {
        private ManipularDB AcessoDB;
        private int intTipoOperacao;
        private Estabelecimentos estabelecimento;
        private Localizacao localizacao;
        private string strArquivoFoto;

        public TelaCadastro(int intTipoOperacao, ManipularDB AcessoDB, Estabelecimentos estabelecimentoAtual)
        {
            localizacao = new Localizacao();
            strArquivoFoto = "";

            InitializeComponent();

            this.AcessoDB = AcessoDB;
            this.intTipoOperacao = intTipoOperacao;

            ObterLocalizacao();

            if (intTipoOperacao == 1)
                estabelecimento = new Estabelecimentos();
            else
            {
                estabelecimento = estabelecimentoAtual;
                BindingContext = estabelecimento;
            }
        }

        public void GravarClick(object sender, EventArgs args)
        {
            try
            {
                if (fldNomeEstabelecimento.Text.Equals("") || fldEndereco.Text.Equals("") || fldBairro.Text.Equals("") || fldCidade.Text.Equals("") || fldTelefone.Text.Equals(""))
                    DisplayAlert("Mensagem alerta","Há campos obrigatórios em branco!","OK");
                else
                {
                    if (intTipoOperacao == 1)
                    {
                        estabelecimento.NomeEstabelecimento = fldNomeEstabelecimento.Text;
                        estabelecimento.TipoEstabelecimento = fldTipoEstabelecimento.SelectedIndex;
                        estabelecimento.Endereco = fldEndereco.Text;
                        estabelecimento.Bairro = fldBairro.Text;
                        estabelecimento.Cidade = fldCidade.Text;
                        estabelecimento.Estado = fldEstado.SelectedIndex;
                        estabelecimento.Telefone = fldTelefone.Text;
                        estabelecimento.Email = fldEmail.Text;
                        estabelecimento.NivelAtendimento = fldNivelAtendimento.SelectedIndex;
                        estabelecimento.QualidadePrato = fldQualidadePrato.SelectedIndex;
                        estabelecimento.ClassificacaoPreco = fldClassificacaoPreco.SelectedIndex;
                        estabelecimento.TipoLocalizacao = fldTipoLocalizacao.SelectedIndex;
                        estabelecimento.Latitude = localizacao.Latitude;
                        estabelecimento.Longitude = localizacao.Longitude;
                        estabelecimento.ArquivoFoto = strArquivoFoto;

                        AcessoDB.Adicionar(estabelecimento);
                    }
                    else
                    {
                        estabelecimento.Latitude = localizacao.Latitude;
                        estabelecimento.Longitude = localizacao.Longitude;
                        estabelecimento.ArquivoFoto = strArquivoFoto;
                        AcessoDB.Gravar(estabelecimento);
                    }

                    Navigation.PopAsync();
                }
            }
            catch
            {
                DisplayAlert("Mensagem alerta", "Há campos obrigatórios em branco!", "OK");
            }
        }

        public async void ObterLocalizacao()
        {
            try
            {
                var varLocalizacao = CrossGeolocator.Current;
                varLocalizacao.DesiredAccuracy = 50;

                var varPosicao = await varLocalizacao.GetPositionAsync(timeoutMilliseconds: 500000);
                localizacao.Latitude = varPosicao.Latitude;
                localizacao.Longitude = varPosicao.Longitude;
            }
            catch
            {
                await DisplayAlert("Mensagem alerta", "Não foi possível acessar o recurso de geolocalização do dispositivo!", "OK");
            }
        }

        public async void FotografarClick(object sender, EventArgs args)
        {
            await CrossMedia.Current.Initialize();

            if (!CrossMedia.Current.IsCameraAvailable || !CrossMedia.Current.IsTakePhotoSupported)
                await DisplayAlert("Mensagem alerta", "Câmera não disponível!", "OK");
            else
            {
                var varArquivoFoto = await CrossMedia.Current.TakePhotoAsync(
                    new StoreCameraMediaOptions
                    {
                        SaveToAlbum = true,
                        Directory = "BonsPratos",
                        Name = "BonsPratos.jpg"
                    });

                if (varArquivoFoto != null)
                    strArquivoFoto = varArquivoFoto.AlbumPath;
            }
        }

    }
}