﻿using System;
using System.ComponentModel;
using System.Globalization;

namespace MultiCalcV2.Model
{
    public class CalculadoraModel : INotifyPropertyChanged
    {
        private bool blnDecimal, blnOperador;
        private double dblValorVisor, dblOperando1, dblOperando2, dblResultado;
        private int intDigitos,intFatorDivisao;
        private char chrOperador;
        private string strTextoVisor;

        public CalculadoraModel()
        {
            blnDecimal = false;
            blnOperador = false;
            intFatorDivisao = 1;
            dblValorVisor = 0;
            dblOperando1 = 0;
            dblOperando2 = 0;
            dblResultado = 0;
            intDigitos = 0;
            chrOperador = ' ';
            strTextoVisor = "0";
        }

        public bool Virgula
        {
            get
            {
                return blnDecimal;
            }

            set
            {
                blnDecimal = value;
            }
        }

        public bool Operador
        {
            get
            {
                return blnOperador;
            }

            set
            {
                blnOperador = value;
            }
        }

        public int FatorDivisao
        {
            get
            {
                return intFatorDivisao;
            }

            set
            {
                intFatorDivisao = value;
            }
        }

        public double ValorVisor
        {
            get
            {
                return dblValorVisor;
            }

            set
            {
                dblValorVisor = value;
            }
        }

        public double PrimeiroOperando
        {
            get
            {
                return dblOperando1;
            }

            set
            {
                dblOperando1 = value;
            }
        }

        public double SegundoOperando
        {
            get
            {
                return dblOperando2;
            }

            set
            {
                dblOperando2 = value;
            }
        }

        public double Resultado
        {
            get
            {
                return dblResultado;
            }

            set
            {
                dblResultado = value;
            }
        }

        public int Digitos
        {
            get
            {
                return intDigitos;
            }

            set
            {
                intDigitos = value;
            }
        }

        public char SinalOperador
        {
            get
            {
                return chrOperador;
            }

            set
            {
                chrOperador = value;
            }
        }


        public string TextoVisor
        {
            get
            {
                return strTextoVisor;
            }

            set
            {
                strTextoVisor = value;
                this.PropertyChanged?.Invoke(this, new PropertyChangedEventArgs(nameof(TextoVisor)));
            }
        }

        public void ConverterValor()
        {
            strTextoVisor = String.Format(new CultureInfo("pt-BR"), "{0:0.00}", dblValorVisor);
        }

        public void Inicializar()
        {
            dblOperando1 = 0.0;
            dblOperando2 = 0.0;
            intDigitos = 0;
            intFatorDivisao = 1;
            blnDecimal = false;
            blnOperador = false;
            chrOperador = ' ';
        }

        public double ConverterRadianos(double dblValorAngulo) => (dblValorAngulo * 0.0174532925);

        public void Calcular()
        {
            if (!blnOperador)
            {
                dblOperando1 = dblValorVisor;
                dblValorVisor = 0.0;
            }
            else
            {
                dblOperando2 = dblValorVisor;

                switch (chrOperador)
                {
                    case '/':
                        if (dblOperando2 > 0.0)
                            dblResultado = dblOperando1 / dblOperando2;
                        break;
                    case 'X':
                        dblResultado = dblOperando1 * dblOperando2;
                        break;
                    case '-':
                        dblResultado = dblOperando1 - dblOperando2;
                        break;
                    case '+':
                        dblResultado = dblOperando1 + dblOperando2;
                        break;
                }

                dblOperando1 = dblResultado;
                dblValorVisor = dblResultado;
            }

            ConverterValor();
            blnDecimal = false;
        }

        public void LimparEntrada()
        {
            dblValorVisor = 0.0;
            intDigitos = 0;
            blnDecimal = false;
            blnOperador = false;

            ConverterValor();
        }

        public void LimparTudo()
        {
            dblValorVisor = 0.0;
            dblResultado = 0.0;

            Inicializar();
            ConverterValor();
        }

        public void ElevarQuadrado()
        {
            dblResultado = dblValorVisor * dblValorVisor;
            dblValorVisor = dblResultado;

            ConverterValor();
            Inicializar();
        }

        public void RaizQuadrada()
        {
            dblResultado = Math.Sqrt(dblValorVisor);
            dblValorVisor = dblResultado;

            ConverterValor();
            Inicializar();
        }

        public void CalcularSeno()
        {
            dblResultado = Math.Sin(ConverterRadianos(dblValorVisor));
            dblValorVisor = dblResultado;

            ConverterValor();
            Inicializar();
        }

        public void CalcularCosseno()
        {
            dblResultado = Math.Cos(ConverterRadianos(dblValorVisor));
            dblValorVisor = dblResultado;

            ConverterValor();
            Inicializar();
        }

        public void CalcularTangente()
        {
            dblResultado = Math.Tan(ConverterRadianos(dblValorVisor));
            dblValorVisor = dblResultado;

            ConverterValor();
            Inicializar();
        }

        public void CalcularFatorial()
        {
            dblResultado = 1;

            for (int intContador = 2; intContador <= (int)dblValorVisor; intContador++)
                dblResultado *= intContador;

            dblValorVisor = dblResultado;

            ConverterValor();
            Inicializar();
        }

        public void ConverterMedida(int intOpcaoConversao)
        {
            double[] dblFatorMultiplicacao = { 2.54, 0.3937, 1.609, 0.6214, 16.387064, 0.0610237, 3.7854117, 0.2642, 0.4536, 2.205, 0.4047, 2.471 };

            dblResultado = dblValorVisor * dblFatorMultiplicacao[intOpcaoConversao];
            dblValorVisor = dblResultado;

            ConverterValor();
            Inicializar();
        }

        public event PropertyChangedEventHandler PropertyChanged;
    }
}
